@@ -4,12 +4,10 @@
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef GRANTLEETHEME_PALETTE_H
-#define GRANTLEETHEME_PALETTE_H
+#pragma once
 
 namespace Palette
 {
 void registerMetaType();
 }
 
-#endif // GRANTLEETHEME_PALETTE_H
